# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta
from __future__ import print_function
from __future__ import unicode_literals
from __future__ import absolute_import
from __future__ import division

import os

from django.utils.translation import ugettext as _
from django import forms
from django.forms.formsets import formset_factory

from fal_validinfo import (
    RemotePortNumber,
)
from project.forms.fields.extras.validators.fal import FALValidator


ACCESSKEY_MAX_LENGTH = 255
SECRETKEY_MAX_LENGTH = 255
BUCKET_MAX_LENGTH = 63
BUCKET_MIN_LENGTH = 3
ENDPOINT_MAX_LENGTH = 255
UPLOAD_MAX_FILE_SIZE = 5 * 1024 * 1024
INITIAL_UPLOAD_MAX_FILE_SIZE = 10 * 1024


class NameField(forms.CharField):
    def __init__(self, *args, **kwargs):
        kwargs['label'] = kwargs.get('label', '接続名')
        super(NameField, self).__init__(*args, **kwargs)


class AccesskeyValidator(FALValidator):
    validator = 'NoCheck'
    options = {
        'max_length': ACCESSKEY_MAX_LENGTH,
    }
class AccesskeyField(forms.CharField):
    def __init__(self, *args, **kwargs):
        kwargs['label'] = kwargs.get('label', 'アクセスキー')
        kwargs['validators'] = kwargs.get('validators', [AccesskeyValidator()])
        super(AccesskeyField, self).__init__(*args, **kwargs)


class SecretkeyValidator(FALValidator):
    validator = 'NoCheck'
    options = {
        'max_length': SECRETKEY_MAX_LENGTH,
    }
class SecretkeyField(forms.CharField):
    def __init__(self, *args, **kwargs):
        kwargs['label'] = kwargs.get('label', 'シークレットキー')
        kwargs['validators'] = kwargs.get('validators', [SecretkeyValidator()])
        super(SecretkeyField, self).__init__(*args, **kwargs)


class HttpmethodField(forms.ChoiceField):
    def __init__(self, *args, **kwargs):
        kwargs['label'] = kwargs.get('label', 'プロトコル')
        kwargs['widget'] = kwargs.get('widget', forms.widgets.RadioSelect)
        kwargs['choices'] = kwargs.get('choices', [
            ('http', 'http'),
            ('https', 'https'),
        ])
        kwargs['initial'] = kwargs.get('initial', kwargs['choices'][1][0])
        super(HttpmethodField, self).__init__(*args, **kwargs)


class StorageclassField(forms.ChoiceField):
    def __init__(self, *args, **kwargs):
        kwargs['label'] = kwargs.get('label', 'ストレージクラス')
        kwargs['widget'] = kwargs.get('widget', forms.widgets.RadioSelect)
        kwargs['choices'] = kwargs.get('choices', [
            ('STANDARD', 'STANDARD'),
            ('RRS', 'RRS'),
        ])
        kwargs['initial'] = kwargs.get('initial', kwargs['choices'][0][0])
        super(StorageclassField, self).__init__(*args, **kwargs)


class EndpointValidator(FALValidator):
    validator = 'NoCheck'
    options = {
        'max_length': ENDPOINT_MAX_LENGTH,
    }
class EndpointField(forms.CharField):
    def __init__(self, *args, **kwargs):
        kwargs['label'] = kwargs.get('label', 'エンドポイント')
        kwargs['initial'] = kwargs.get('initial', 'jp-east-2.storage.api.nifcloud.com')
        kwargs['validators'] = kwargs.get('validators', [EndpointValidator()])
        super(EndpointField, self).__init__(*args, **kwargs)


class PortNumberValidator(FALValidator):
    validator = RemotePortNumber.VALIDATOR
    options = {
    }
class PortNumberField(forms.CharField):
    def __init__(self, *args, **kwargs):
        kwargs['label'] = kwargs.get('label', 'ポート番号')
        kwargs['validators'] = kwargs.get('validators', [PortNumberValidator()])
        super(PortNumberField, self).__init__(*args, **kwargs)


class MultipartUploadField(forms.BooleanField):
    def __init__(self, *args, **kwargs):
        kwargs['label'] = kwargs.get('label', 'マルチパートアップロードを有効にする')
        kwargs['required'] = kwargs.get('required', False)
        super(MultipartUploadField, self).__init__(*args, **kwargs)
